@@ -8,10 +8,22 @@ fittedModel <- glmer(observedResponse ~ Environment1 + (1|group),
 simulationOutput <- simulateResiduals(fittedModel = fittedModel)
 
 # plot residuals, quantreg = T is better but costs more time
-plotSimulatedResiduals(simulationOutput = simulationOutput, quantreg = FALSE)
+plot(simulationOutput, quantreg = FALSE)
+
+# the calculated residuals can be accessed via 
+residuals(simulationOutput)
+simulationOutput$scaledResiduals
+
+# calculating summaries per group
+simulationOutput = recalculateResiduals(simulationOutput, group = testData$group)
+plot(simulationOutput, quantreg = FALSE)
 
 # create simulations with refitting, n=5 is very low, set higher when using this
 simulationOutput <- simulateResiduals(fittedModel = fittedModel, 
                                       n = 10, refit = TRUE)
-plotSimulatedResiduals(simulationOutput = simulationOutput, quantreg = FALSE)
+plot(simulationOutput, quantreg = FALSE)
+
+# grouping per random effect group works as above
+simulationOutput = recalculateResiduals(simulationOutput, group = testData$group)
+plot(simulationOutput, quantreg = FALSE)
 
